@@ -5,6 +5,8 @@
 # import asyncio
 import base64
 import requests
+import random
+import string
 
 # declare global variables
 global HEADERS
@@ -336,6 +338,22 @@ class KnowledgeBase:
         resp_body = kb_file.create()
         return resp_body
 
+    def get_files(self):
+        url = BASE_URL + f'knowledge_bases/{self.kb_id}/files'
+        resp = _format_http_response(requests.get(url, headers=HEADERS))
+        files = {}
+        for file in resp['body']:
+            kb_file = KnowledgeBaseFile(
+                kb_id=file['id'],
+                content=file['content'],
+                title=file['title'],
+                link_to_source=file['link_to_source'],
+                supp_id=file['supp_id'],
+                description=file['description'],
+            )
+            files[file['id']] = kb_file
+        return files
+
 
 class KnowledgeBaseFile:
     def __init__(self, kb_id: str, content: str, title: str = None, link_to_source: str = None, supp_id: str = None, description: str = None):
@@ -372,13 +390,7 @@ def model_spec_preprocessing(model_spec: dict):
         for incantation_name in incantation_names:
             incantation_ids.append(get_incantation(incantation_name).incantation_id)
         model_spec["incantation_ids"] = incantation_ids
-        del model_spec["incantation_names"]
-
-    """
-    # if temperature is in the model_spec, convert it to a string
-    if "temperature" in model_spec:
-        model_spec["temperature"] = str(model_spec["temperature"])"""
-    
+        del model_spec["incantation_names"] 
     return model_spec
 
 # create_incantation() is a convenience function that creates an Incantation object and then calls its create() method
@@ -515,6 +527,16 @@ def list_knowledge_bases(verbose=False):
             print (f"id: {kb_obj.kb_id}\ntitle: {kb_obj.title}\n")
     return knowledge_bases
 
+# list_files() is a convenience function that returns a dictionary of File objects for an existing knowledge base, given its title
+def list_files_in_kb(kb_title: str, verbose=False):
+    kb = get_knowledge_base(kb_title)
+    files = kb.get_files()
+    if verbose:
+        print ("\nFiles:")
+        for file_obj in files.values():
+            print (f"title: {file_obj.title}\ncontent: {file_obj.content[:100]}\n\n")
+    return files
+
 # add a file to a knowledge base
 def add_file_to_kb(kb_title: str, file_path: str, file_type: str = None):
     kb = get_knowledge_base(kb_title)
@@ -528,28 +550,6 @@ def add_file_to_kb(kb_title: str, file_path: str, file_type: str = None):
     else:
         raise Exception("File type not supported: " + file_type)
     
-    kb.add_file(content=content, title="Title")
-
-
-"""
-Functions to expose to the user:
-- init()
-- create_incantation()
-- get_incantation()
-- update_incantation()
-- create_model()
-- get_model()
-- update_model()
-- list_incantations()
-- list_models()
-- list_instances()
-- Model
-    - create_instance()
-- ModelInstance
-    - respond()
-- KnowledgeBase
-    - add_file()
-
-We probably need to make users aware of the classes, but we generally want to discourage them from using them directly, because it's easier to just use the convenience functions.
-
-"""
\ No newline at end of file
+    # make the title a random string
+    title = ''.join(random.choices(string.ascii_uppercase + string.digits, k=10))
+    kb.add_file(content=content, title=title)
\ No newline at end of file
